==> ooo_dev_tools-0.25.1-py3-none-any.whl: ooodev/format/draw/modify/area/__init__.py <==
import uno
from ooo.dyn.awt.gradient_style import GradientStyle as GradientStyle
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ooodev.format.draw.style.kind import DrawStyleFamilyKind as DrawStyleFamilyKind
from ooodev.format.draw.style.lookup import FamilyCell as FamilyCell
from ooodev.format.draw.style.lookup import FamilyDefault as FamilyDefault
from ooodev.format.draw.style.lookup import FamilyGraphics as FamilyGraphics
from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.direct.write.fill.area.img import OffsetColumn as OffsetColumn
from ooodev.format.inner.direct.write.fill.area.img import OffsetRow as OffsetRow
from ooodev.format.inner.direct.write.fill.area.img import SizePercent as SizePercent
from ooodev.format.inner.preset.preset_gradient import PresetGradientKind as PresetGradientKind
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import PresetPatternKind as PresetPatternKind
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.offset import Offset as Offset
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

from .color import Color as Color
from .gradient import Gradient as Gradient
from .img import Img as Img
from .pattern import Pattern as Pattern
from .hatch import Hatch as Hatch

__all__ = ["Color", "Gradient", "Hatch", "Img", "Pattern"]

==> ooo_dev_tools-0.53.0-py3-none-any.whl: ooodev/format/draw/modify/area/__init__.py <==
from ooo.dyn.awt.gradient_style import GradientStyle as GradientStyle
from ooo.dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ooo.dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ooodev.format.draw.style.kind import DrawStyleFamilyKind as DrawStyleFamilyKind
from ooodev.format.draw.style.lookup import FamilyCell as FamilyCell
from ooodev.format.draw.style.lookup import FamilyDefault as FamilyDefault
from ooodev.format.draw.style.lookup import FamilyGraphics as FamilyGraphics
from ooodev.format.inner.direct.write.fill.area.img import ImgStyleKind as ImgStyleKind
from ooodev.format.inner.common.format_types.offset_column import (
    OffsetColumn as OffsetColumn,
)
from ooodev.format.inner.common.format_types.offset_row import OffsetRow as OffsetRow
from ooodev.format.inner.common.format_types.size_percent import (
    SizePercent as SizePercent,
)
from ooodev.format.inner.preset.preset_gradient import (
    PresetGradientKind as PresetGradientKind,
)
from ooodev.format.inner.preset.preset_hatch import PresetHatchKind as PresetHatchKind
from ooodev.format.inner.preset.preset_image import PresetImageKind as PresetImageKind
from ooodev.format.inner.preset.preset_pattern import (
    PresetPatternKind as PresetPatternKind,
)
from ooodev.utils.data_type.color_range import ColorRange as ColorRange
from ooodev.utils.data_type.intensity_range import IntensityRange as IntensityRange
from ooodev.utils.data_type.offset import Offset as Offset
from ooodev.utils.data_type.size_mm import SizeMM as SizeMM

from .color import Color as Color
from .gradient import Gradient as Gradient
from .img import Img as Img
from .pattern import Pattern as Pattern
from .hatch import Hatch as Hatch

__all__ = ["Color", "Gradient", "Hatch", "Img", "Pattern"]

import uno  # noqa # type: ignore
